# llmabstractions
![pytest](https://github.com/dialectos-ai/llmabstractions/actions/workflows/python-app.yml/badge.svg)  ![pytest-nightly](https://github.com/dialectos-ai/llmabstractions/actions/workflows/python-nightly-tests.yml/badge.svg) [![Documentation Status](https://readthedocs.org/projects/llmabstractions/badge/?version=latest)](https://omicspylib.readthedocs.io/en/latest/?badge=latest)

A Python library, abstracting the way you interact with LLMs
